from django import forms

from .models import ParametersCell
from jsonfield.widgets import JSONWidget

class ParametersForm(forms.Form):
    choice = forms.ChoiceField(choices=[])

    def __init__(self, *args, **kwargs):
        self.parameters = kwargs.pop('parameters')
        empty_label = kwargs.pop('empty_label')
        super(ParametersForm, self).__init__(*args, **kwargs)
        self.fields['choice'].choices = [('', empty_label)] + [(x['name'], x['name']) for x in self.parameters]

    def clean(self):
        choice = self.cleaned_data.get('choice')
        for parameter in self.parameters:
            if parameter['name'] == choice:
                self.cleaned_data['choice'] = parameter['value']
                break
        return self.cleaned_data

class ParametersCellForm(forms.ModelForm):
    class Meta:
        model = ParametersCell
        fields = ('title', 'url', 'empty_label', 'parameters',)
        widgets = {
            # XXX: replace with a more ergonomic widget
            'parameters': JSONWidget(
                attrs={
                    'rows': 30,
                    'cols': 100,
                    'style': 'resize: none'
                })
        }
